# OTE-API OPTIMADE Strategies

This page provides documentation for the `oteapi_optimade.strategies` submodule, where all the OTE-API OPTIMADE strategies are located.

These strategies will be available when setting up a server in an environment with oteapi-optimade installed.

::: oteapi_optimade.strategies
